@@ -59,14 +59,35 @@ class _SqlServer2005FuncHelper(db._GenericAdvFuncHelper):
         'Interval' : 'interval',
         'Password' : 'varbinary(255)',
         'Bytes' :    'varbinary(max)',
+        'SizeConstrainedString': 'nvarchar(%s)',
         }
 
     def list_tables(self, cursor):
         """return the list of tables of a database"""
         cursor.execute('''sys.sp_tables @table_type = "'TABLE'"''')
         return [row[2] for row in cursor.fetchall()]
-#        cursor.tables()
-#        return  [row.table_name for row in cursor.fetchall()]
+        # cursor.tables()
+        # return  [row.table_name for row in cursor.fetchall()]
+
+    def list_indices(self, cursor, table=None):
+        """return the list of indices of a database, only for the given table if specified"""
+        sql = "SELECT name FROM sys.indexes"
+        if table:
+            sql = ("SELECT ind.name FROM sys.indexes as ind, sys.objects as obj WHERE "
+                   "obj.object_id = ind.object_id AND obj.name = '%s'"
+                   % table)
+        cursor.execute(sql)
+        return [r[0] for r in cursor.fetchall()]
+
+    def list_indices(self, cursor, table=None):
+        """return the list of indices of a database, only for the given table if specified"""
+        sql = "SELECT name FROM sys.indexes"
+        if table:
+            sql = ("SELECT ind.name FROM sys.indexes as ind, sys.objects as obj WHERE "
+                   "obj.object_id = ind.object_id AND obj.name = '%s'"
+                   % table)
+        cursor.execute(sql)
+        return [r[0] for r in cursor.fetchall()]
 
     def binary_value(self, value):
         return StringIO.StringIO(value)
@@ -75,8 +96,7 @@ class _SqlServer2005FuncHelper(db._GenericAdvFuncHelper):
                         dbname=None, dbhost=None, dbport=None, dbuser=None):
         return [[sys.executable, os.path.normpath(__file__),
                  "_SqlServer2005FuncHelper._do_backup", dbhost or self.dbhost,
-                 dbname or self.dbname, backupfile]
-                ]
+                 dbname or self.dbname, backupfile]]
 
     def restore_commands(self, backupfile, keepownership=True, drop=True,
                          dbname=None, dbhost=None, dbport=None, dbuser=None,
@@ -87,12 +107,24 @@ class _SqlServer2005FuncHelper(db._GenericAdvFuncHelper):
                 ]
 
 
+    def sql_concat_string(self, lhs, rhs):
+        return '%s + %s' % (lhs, rhs)
 
     def sql_temporary_table(self, table_name, table_schema,
                             drop_on_commit=True):
         table_name = self.temporary_table_name(table_name)
         return "CREATE TABLE %s (%s);" % (table_name, table_schema)
 
+    def sql_change_col_type(self, table, column, coltype, null_allowed):
+        if null_allowed:
+            cmd = 'ALTER TABLE %s ALTER COLUMN %s %s NULL'
+        else:
+            cmd = 'ALTER TABLE %s ALTER COLUMN %s %s NOT NULL'
+        return cmd % (table, column, coltype)
+
+    def sql_set_null_allowed(self, table, column, coltype, null_allowed):
+        return self.sql_change_col_type(table, column, coltype, null_allowed)
+
     def temporary_table_name(self, table_name):
         if not table_name.startswith('#'):
             table_name = '#' + table_name
